@@ -736,6 +736,17 @@ void get_cookie_string(char* key, char* buf)
     strcpy(buf, value_base64);
 }
 
+void set_timestamp_string(char* buf)
+{
+    struct timeval tv;
+    struct tm *tp;
+
+    gettimeofday(&tv, NULL);
+    tp = localtime(&tv.tv_sec);
+    sprintf(buf, "%04d-%02d-%02d-%02d-%02d-%02d",
+            tp->tm_year + 1900, tp->tm_mon + 1, tp->tm_mday,
+            tp->tm_hour, tp->tm_min, tp->tm_sec);
+}
 void set_date_string(char* buf)
 {
     struct timeval tv;
